import { Form, Input, InputNumber, Modal } from "antd";
import { useAssessmentStandardContext } from "./assessment-standard-provider";
export default function AssessmentModal() {
    const { isAgeModalVisible, isScoreModalVisible, ageForm, scoreForm, handleAgeOk, handleAgeCancel, handleScoreOk, handleScoreCancel, ageRanges } = useAssessmentStandardContext();
    return (
        <div>
            <Modal
                title="添加年龄范围"
                open={isAgeModalVisible}
                onOk={ageForm.submit}
                onCancel={handleAgeCancel}
            >
                <Form form={ageForm} onFinish={handleAgeOk}>
                    <Form.Item
                        name="start"
                        label="起始年龄"
                        rules={[
                            { required: true },
                            ({ getFieldValue }) => ({
                                validator(_, value) {
                                    const end = getFieldValue('end');
                                    if (end && value > end) {
                                        return Promise.reject(new Error('起始年龄不能大于结束年龄'));
                                    }
                                    return Promise.resolve();
                                },
                            }),
                        ]}
                    >
                        <InputNumber min={0} />
                    </Form.Item>
                    <Form.Item
                        name="end"
                        label="结束年龄"
                        rules={[
                            ({ getFieldValue }) => ({
                                validator(_, value) {
                                    const start = getFieldValue('start');
                                    if (value && start > value) {
                                        return Promise.reject(new Error('结束年龄不能小于起始年龄'));
                                    }
                                    return Promise.resolve();
                                },
                            }),
                        ]}
                    >
                        <InputNumber min={0} />
                    </Form.Item>
                </Form>
            </Modal>
            <Modal
                title="添加分数与对应标准"
                open={isScoreModalVisible}
                onOk={scoreForm.submit}
                onCancel={handleScoreCancel}
            >
                <Form form={scoreForm} onFinish={handleScoreOk}>
                    <Form.Item name="score" label="分数" rules={[{ required: true }]}>
                        <Input min={0} />
                    </Form.Item>
                    {ageRanges.map((range, index) => (
                        <Form.Item key={index} name={`standards_${index}`} label={range.label}>
                            <Input min={0} />
                        </Form.Item>
                    ))}
                </Form>
            </Modal>
        </div>
    )
}