import { api } from "@nice/client";
import { useMainContext } from "../layout/MainProvider";
import toast from "react-hot-toast";
import { Form, Modal, Select, Radio } from "antd";
import { useState } from "react";

export default function DailyModal() {
  const { form, visible, setVisible, editingRecord, setEditingRecord } = useMainContext();
  const [submitting, setSubmitting] = useState(false);
  // 获取更新和创建的mutation
  const updateMutation = api.trainSituation.update.useMutation();
  const createMutation = api.trainSituation.create.useMutation();
  // 获取员工列表
  const { data: staffs } = api.staff.findMany.useQuery({
    where: {
      deletedAt: null
    },
    include: {
      position: true,
    },
  });
  // console.log('wd', staffs);


  // 获取训练内容列表
  const { data: trainContents } = api.trainContent.findMany.useQuery({});

  const handleOk = async () => {
    try {
      console.log('handleOk 开始执行');
      const values = await form.validateFields();
      console.log('表单验证通过，值:', values);
      setSubmitting(true);
      // 根据 TrainSituation 模型构建数据
      const trainData = {
        staffId: values.staffId,
        trainContentId: values.trainContentId,
        mustTrainTime: 1, // 预期训练时间
        alreadyTrainTime: values.isPresent ? 1 : 0, // 实际训练时间
        value: values.content, // 训练内容描述
        score: values.isPresent ? 1 : 0,
      };
      if (editingRecord?.id) {
        await updateMutation.mutateAsync({
          where: { id: editingRecord.id },
          data: trainData
        });
      } else {
        await createMutation.mutateAsync({
          data: trainData
        });
      }
      console.log('操作成功');
      toast.success("保存成功");
      setVisible(false);
      setEditingRecord(null);
      form.resetFields();
    } catch (error) {
      console.error("保存失败:", error);
      toast.error("保存失败");
    } finally {
      setSubmitting(false);
    }
  };
  const handleCancel = () => {
    setVisible(false);
    setEditingRecord(null);
    form.resetFields();
  };
  // useEffect(() => {
  //   if (visible && editingRecord) {
  //     form.setFieldsValue(editingRecord);
  //   }
  // }, [visible, editingRecord]);
  return (
    <Modal
      title="每日训练填报"
      open={visible}
      onOk={handleOk}
      onCancel={handleCancel}
      confirmLoading={submitting}
    >
      <Form
        form={form}
        layout="vertical"
      >
        <Form.Item
          name="staffId"
          label="人员"
          rules={[{ required: true, message: '请选择人员' }]}
        >
          <Select
            placeholder="请选择人员"
            options={staffs?.map(staff => ({
              label: `${staff.showname || staff.username || '未知'} ${staff.positionId || '无职务'})}`,
              value: staff.id  
            }))}
          />
        </Form.Item>
        {/* <Form.Item
          name="position"
          label="职务"
        >
          <Input disabled />
        </Form.Item> */}

        <Form.Item
          name="trainContentId"
          label="训练科目"
          rules={[{ required: true, message: '请选择训练科目' }]}
        >
          <Select
            placeholder="请选择训练科目"
            options={trainContents?.map(item => ({
              label: item.title,
              value: item.id
            }))}
          />
        </Form.Item>
        {/* <Form.Item
          name="content"
          label="训练内容"
          rules={[{ required: true, message: '请填写训练内容' }]}
        >
          <Input.TextArea rows={4} placeholder="请输入今日训练内容" />
        </Form.Item> */}
        <Form.Item
          name="isPresent"
          label="在位情况"
          rules={[{ required: true, message: '请选择在位情况' }]}
          initialValue={true}
        >
          <Radio.Group>
            <Radio value={true}>在位</Radio>
            <Radio value={false}>不在位</Radio>
          </Radio.Group>
        </Form.Item>
      </Form>
    </Modal>
  );
} 