import React, { useContext, useEffect, useState } from "react";
import { Form,Input } from "antd";



// 创建可编辑单元格组件
export const EditableContext = React.createContext(null);
export const EditableRow = ({ index, ...props }) => {
  const [form] = Form.useForm();
  return (
    <Form form={form} component={false}>
      <EditableContext.Provider value={form}>
        <tr {...props} />
      </EditableContext.Provider>
    </Form>
  );
};
export const EditableCell = ({
    title,
    editable,
    children,
    dataIndex,
    record,
    handleSave,
    ...restProps
  }) => {
    const form = useContext(EditableContext);
  
    useEffect(() => {
      if (editable) {
        form.setFieldsValue({ [dataIndex]: record[dataIndex] });
      }
    }, [form, dataIndex, record, editable]);
  
    const save = async () => {
      try {
        const values = await form.validateFields();
        handleSave({ ...record, ...values });
      } catch (errInfo) {
        console.log('保存失败:', errInfo);
      }
    };
  
    let childNode = children;
  
    if (editable) {
      childNode = (
        <Form.Item
          style={{ margin: 0 }}
          name={dataIndex}
          rules={[
            {
              required: true,
              message: `${title}不能为空！`,
            },
          ]}
        >
          <Input onPressEnter={save} onBlur={save} />
        </Form.Item>
      );
    }
  
    return <td {...restProps}>{childNode}</td>;
  };